==> webknossos-0.10.24.tar.gz: webknossos-0.10.24/webknossos/client/_generated/api/default/current_user_info.py <==
from typing import Any, Dict, Optional

import httpx

from ...client import Client
from ...models.current_user_info_response_200 import CurrentUserInfoResponse200
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/api/user".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[CurrentUserInfoResponse200]:
    if response.status_code == 200:
        response_200 = CurrentUserInfoResponse200.from_dict(response.json())

        return response_200
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[CurrentUserInfoResponse200]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
) -> Response[CurrentUserInfoResponse200]:
    kwargs = _get_kwargs(
        client=client,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
) -> Optional[CurrentUserInfoResponse200]:
    """ """

    return sync_detailed(
        client=client,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
) -> Response[CurrentUserInfoResponse200]:
    kwargs = _get_kwargs(
        client=client,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
) -> Optional[CurrentUserInfoResponse200]:
    """ """

    return (
        await asyncio_detailed(
            client=client,
        )
    ).parsed

==> webknossos-0.12.3.tar.gz: webknossos-0.12.3/webknossos/client/_generated/api/default/current_user_info.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional

import httpx

from ...client import Client
from ...models.current_user_info_response_200 import CurrentUserInfoResponse200
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/api/user".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[CurrentUserInfoResponse200]:
    if response.status_code == HTTPStatus.OK:
        response_200 = CurrentUserInfoResponse200.from_dict(response.json())

        return response_200
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[CurrentUserInfoResponse200]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
) -> Response[CurrentUserInfoResponse200]:
    """Returns a json with information about the requesting user

    Returns:
        Response[CurrentUserInfoResponse200]
    """

    kwargs = _get_kwargs(
        client=client,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
) -> Optional[CurrentUserInfoResponse200]:
    """Returns a json with information about the requesting user

    Returns:
        Response[CurrentUserInfoResponse200]
    """

    return sync_detailed(
        client=client,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
) -> Response[CurrentUserInfoResponse200]:
    """Returns a json with information about the requesting user

    Returns:
        Response[CurrentUserInfoResponse200]
    """

    kwargs = _get_kwargs(
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
) -> Optional[CurrentUserInfoResponse200]:
    """Returns a json with information about the requesting user

    Returns:
        Response[CurrentUserInfoResponse200]
    """

    return (
        await asyncio_detailed(
            client=client,
        )
    ).parsed
